@@ -73,7 +73,7 @@ inline
 #endif
 #endif
 static unsigned int
-hash_Entity (register const char *str, register unsigned int len)
+hash_Entity (const char *str, unsigned int len)
 {
   static const unsigned short asso_values[] =
     {
@@ -104,7 +104,7 @@ hash_Entity (register const char *str, register unsigned int len)
       932, 932, 932, 932, 932, 932, 932, 932, 932, 932,
       932, 932, 932, 932, 932, 932, 932
     };
-  register int hval = len;
+  int hval = len;
 
   switch (hval)
     {
@@ -140,7 +140,7 @@ hash_Entity (register const char *str, register unsigned int len)
 __inline
 #endif
 const struct entity *
-kde_findEntity (register const char *str, register unsigned int len)
+kde_findEntity (const char *str, unsigned int len)
 {
   enum
     {
@@ -815,15 +815,15 @@ kde_findEntity (register const char *str, register unsigned int len)
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
     {
-      register int key = hash_Entity (str, len);
+      int key = hash_Entity (str, len);
 
       if (key <= MAX_HASH_VALUE && key >= 0)
         {
-          register int index = lookup[key];
+          int index = lookup[key];
 
           if (index >= 0)
             {
-              register const char *s = wordlist_Entity[index].name;
+              const char *s = wordlist_Entity[index].name;
 
               if (*str == *s && !strncmp (str + 1, s + 1, len - 1) && s[len] == '\0')
                 return &wordlist_Entity[index];
