@@ -1509,7 +1509,7 @@ TQT_TQIO_LONG KExtendedSocket::tqwriteBlock(const char *data, TQT_TQIO_ULONG len
 
       // LOCK BUFFER MUTEX
 
-      register unsigned wsize = writeBufferSize();
+      unsigned wsize = writeBufferSize();
       if (d->outMaxSize == (int)wsize) // (int) to get rid of annoying warning
 	{
 	  // buffer is full!
