@@ -525,6 +525,10 @@ TQString KMimeType::iconForURL( const KURL & _url, mode_t _mode )
         // root of protocol: if we found nothing, revert to mimeTypeIcon (which is usually "folder")
         if ( _url.path().length() <= 1 && ( i == unknown || i.isEmpty() ) )
             i = mimeTypeIcon;
+
+        // special case: root directory (/) -- Gitea issue #128
+        if ( _url == KURL("file:///") )
+            i = "folder_red";
     }
     return i;
 }
