@@ -155,8 +155,10 @@ pid_t KRun::runURL( const KURL& u, const TQString& _mimetype, TQWidget* window,
         noAuth = true;
       }
     }
-    else if (_mimetype == "application/x-executable")
+    else if (_mimetype == "application/x-executable" || _mimetype == "application/x-pie-executable")
+    {
       noRun = true;
+    }
   }
   else if ( isExecutable(_mimetype) )
   {
@@ -697,8 +699,12 @@ static pid_t runTempService( const KService& _service, const KURL::List& _urls,
 static KURL::List resolveURLs( const KURL::List& _urls, const KService& _service )
 {
   // Check which protocols the application supports.
-  // This can be a list of actual protocol names, or just TDEIO for KDE apps.
+  // This can be a list of actual protocol names, or just TDEIO for TDE apps, or KIO for KDE apps.
   TQStringList supportedProtocols = _service.property("X-TDE-Protocols").toStringList();
+  if (supportedProtocols.isEmpty())
+  {
+    supportedProtocols = _service.property("X-KDE-Protocols").toStringList();
+  }
   KRunMX1 mx1( _service );
   TQString exec = _service.exec();
   if ( mx1.expandMacrosShellQuote( exec ) && !mx1.hasUrls ) {
@@ -706,9 +712,9 @@ static KURL::List resolveURLs( const KURL::List& _urls, const KService& _service
   } else {
     if ( supportedProtocols.isEmpty() )
     {
-      // compat mode: assume TDEIO if not set and it's a KDE app
+      // compat mode: assume TDEIO if not set and it's a TDE or KDE app
       TQStringList categories = _service.property("Categories").toStringList();
-      if (( categories.find("TDE") != categories.end() ) && ( categories.find("KDE") != categories.end() ))
+      if ((categories.find("TDE") != categories.end()) || (categories.find("KDE") != categories.end()))
          supportedProtocols.append( "TDEIO" );
       else { // if no KDE app, be a bit over-generic
          supportedProtocols.append( "http");
@@ -719,12 +725,13 @@ static KURL::List resolveURLs( const KURL::List& _urls, const KService& _service
   kdDebug(7010) << "supportedProtocols:" << supportedProtocols << endl;
 
   KURL::List urls( _urls );
-  if ( supportedProtocols.find( "TDEIO" ) == supportedProtocols.end() ) {
+  if ((supportedProtocols.find("TDEIO") == supportedProtocols.end()) &&
+      (supportedProtocols.find("KIO") == supportedProtocols.end())) {
     for( KURL::List::Iterator it = urls.begin(); it != urls.end(); ++it ) {
       const KURL url = *it;
       bool supported = url.isLocalFile() || supportedProtocols.find( url.protocol().lower() ) != supportedProtocols.end();
       kdDebug(7010) << "Looking at url=" << url << " supported=" << supported << endl;
-      if ( !supported && KProtocolInfo::protocolClass(url.protocol()) == ":local" )
+      if ((!supported) && (KProtocolInfo::protocolClass(url.protocol()) == ":local"))
       {
         // Maybe we can resolve to a local URL?
         KURL localURL = TDEIO::NetAccess::mostLocalURL( url, 0 );
@@ -1451,6 +1458,7 @@ bool KRun::isExecutable( const TQString& serviceType )
              serviceType == "media/builtin-trash" ||
              serviceType == "media/builtin-webbrowser" ||
              serviceType == "application/x-executable" ||
+             serviceType == "application/x-pie-executable" ||
              serviceType == "application/x-msdos-program" ||
              serviceType == "application/x-shellscript" );
 }
