@@ -104,6 +104,8 @@ KMJobViewer::KMJobViewer(TQWidget *parent, const char *name)
 		conf->setGroup( "Jobs" );
 		resize( conf->readSizeEntry( "Size", &defSize ) );
 	}
+
+	connect(KMFactory::self()->manager(), TQT_SIGNAL(printerListUpdated()),TQT_SLOT(slotPrinterListUpdated()));
 }
 
 KMJobViewer::~KMJobViewer()
@@ -335,7 +337,7 @@ void KMJobViewer::initActions()
 
 		TDEConfig *conf = KMFactory::self()->printConfig();
 		conf->setGroup("Jobs");
-		m_stickybox->setChecked(conf->readBoolEntry("KeepWindow",true));
+		m_stickybox->setChecked(conf->readBoolEntry("KeepWindow",false));
 		connect(m_stickybox, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotKeepWindowChange(bool)));
 		statusbar->addWidget( m_stickybox, 1, false );
 		statusbar->insertItem(" " + i18n("Max.: %1").arg(i18n("Unlimited"))+ " ", 0, 0, true);
@@ -532,6 +534,11 @@ void KMJobViewer::slotRightClicked(TQListViewItem*,const TQPoint& p,int)
 	if (m_pop) m_pop->popup(p);
 }
 
+void KMJobViewer::slotPrinterListUpdated()
+{
+	loadPrinters();
+}
+
 void KMJobViewer::loadPrinters()
 {
 	m_printers.clear();
