@@ -97,6 +97,8 @@ Reference Manual for Version 2.2.x of the GNU C Library */
 
 #ifdef HAVE_GETPT
     master = getpt();
+#elif defined(HAVE_POSIX_OPENTPT)
+    master = posix_openpt(O_RDWR);
 #else
     master = open("/dev/ptmx", O_RDWR);
 #endif
